import sys # https://docs.python.org/3/library/sys.html
import io # https://docs.python.org/3/library/io.html
import requests # https://2.python-requests.org/en/master/
import ftplib # https://docs.python.org/3/library/ftplib.html
import pygame # https://www.pygame.org/news
from datetime import datetime # https://docs.python.org/3/library/datetime.html
from time import sleep

# ak URL obsahuje binarny subor, zisti jeho vlastnosti
def is_binary(url,fn):
    req = requests.head(url,allow_redirects = True) # zaslanie HEAD poziadavky
    header = req.headers # vrati Dict hlavicky z requests.Response
    
    ftype = header.get('Content-Type') # typ suboru
    if ('text' in ftype.lower()): # text
        return False
    if ('html' in ftype.lower()): # html
        return False

    print("Názov súboru: {}".format(fn)) # nazov suboru
    flength = header.get('Content-Length') # velkost prveho suboru
    print("Veľkosť prvého súboru: {} B".format(flength))
    return True

# URL snimky
img_url = "192.168.1.11/snapshot/view0.jpg"
# nazov suboru so snimkou
fname = img_url.split('/')[-1]

# obsahuje URL binarny subor?
if not (is_binary(img_url,fname)):
    sys.exit("Súbor {} nemožno stiahnuť".format(fname))

# inicializacia pygame
pygame.init()
screen = pygame.display.set_mode((64,64)) # okno iba z dovodu KEYDOWN

# FTP login udaje
ftp_site = "ftp.ftp.sk"
ftp_user = "meno"
ftp_pswd = "heslo"
# FTP session
session = ftplib.FTP(ftp_site,ftp_user,ftp_pswd)
# FTP zmena cielovej zlozky na ukladanie snimok
session.cwd("public_html/doc/cam1")
print("Ukladám do zložky: {}".format(session.pwd()))

t = datetime.today() # datetime objekt
tsec = t.second # aktualna sekunda

# programovy loop
while True:
    for event in pygame.event.get():
        # koniec po stlaceni klavesy 'q'
        if (event.type == pygame.KEYDOWN) and (event.key == pygame.K_q):
            print("Koniec...")
            session.quit() # FTP session
            pygame.quit() # pygame
            sys.exit() # program

    t = datetime.today() # datetime objekt
    # synchronizacia a ulozenie snimky po prechode sekund cez 59
    # a nasledne ukladanie po kazdych 20-tich sekundach
    if (t.second < tsec) or (t.second - tsec > 19):
        tsec = t.second
        fn = "c{:02d}_{:02d}{:02d}{:02d}.jpg".format(t.day,t.hour,t.minute,t.second)
        print(fn) # nazov suboru = c den _ hodina minuta sekunda.jpg

        # HTTP GET
        req = requests.get(img_url,allow_redirects = True)
        fdata = io.BytesIO(req.content)

        # FTP STOR
        session.storbinary("STOR {}".format(fn),fdata)

    # 10s spanok...
    sleep(10)
